@@ -423,8 +423,27 @@ class BinaryImageClassificator:
         else:
             self.model = load_model(f"{name}.h5")
 
-    @staticmethod
-    def _oom_avoider():
+    def predict(self, image, image_type=None, accuracy=False):
+        if image_type is None and type(image) is str:
+            image_type = "path"
+        if image_type == "path":
+            img = cv2.imread(image)
+        else:
+            img = image
+        resize = tf.image.resize(img, (256, 256))
+        yhat = self.model.predict(np.expand_dims(resize / 255, 0), verbose=0)
+        if accuracy:
+            if yhat > 0.5:
+                return self.first_class, ((yhat[0][0] - 0.5) * 2) * 100
+            else:
+                return self.second_class, (1 - (yhat[0][0] * 2)) * 100
+        else:
+            if yhat > 0.5:
+                return self.first_class
+            else:
+                return self.second_class
+
+    def _oom_avoider(self):
         if self.gpu_usage:
             gpus = tf.config.experimental.list_physical_devices("GPU")
             for gpu in gpus:
